@@ -6,12 +6,16 @@
 #define CORE_TYPE_ELF32 1
 #define CORE_TYPE_ELF64 2
 
-#define BOOT_BLOCK_VERSION 2
-#define BOOT_BLOCK_LAST_COMP_VERSION 2
-#define NEED_STRUCTURE_BLOCK_EXTRA_PAD
+#define BOOT_BLOCK_VERSION 17
+#define BOOT_BLOCK_LAST_COMP_VERSION 17
+#if (BOOT_BLOCK_VERSION < 16)
+#	define NEED_STRUCTURE_BLOCK_EXTRA_PAD
+#endif
 #define HAVE_DYNAMIC_MEMORY
 #define NEED_RESERVE_DTB
 
+extern int get_devtree_value(const char *fname, unsigned long long *pvalue);
+
 int setup_memory_ranges(unsigned long kexec_flags);
 
 int elf_ppc64_probe(const char *buf, off_t len);
